@@ -163,13 +163,16 @@ var commandCache = {}
 
 npm.spinner =
   { int: null
+  , started: false
   , start: function () {
       if (npm.spinner.int) return
       var c = npm.config.get("spin")
       if (!c) return
       var stream = npm.config.get("logstream")
       var opt = { tty: c !== "always", stream: stream }
+      opt.cleanup = !npm.spinner.started
       npm.spinner.int = charSpin(opt)
+      npm.spinner.started = true
     }
   , stop: function () {
       clearInterval(npm.spinner.int)
@@ -199,8 +202,6 @@ Object.keys(abbrevs).concat(plumbing).forEach(function addCommand (c) {
       }
       if (args.length === 1) args.unshift([])
 
-      npm.spinner.start()
-
       npm.registry.version = npm.version
       if (!npm.registry.refer) {
         npm.registry.refer = [a].concat(args[0]).map(function (arg) {
